package com.yunzhi.shigongli.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.entity.TaResource;
import com.yunzhi.shigongli.entity.TaShop;
import com.yunzhi.shigongli.entity.TaTourist;
import com.yunzhi.shigongli.mapper.TaResourceMapper;
import com.yunzhi.shigongli.mapper.TaTouristMapper;
import com.yunzhi.shigongli.service.ITaTouristService;

import com.yunzhi.shigongli.vo.ResourceFieldVO;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * <p>
 * 旅游景点 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */
@Service
public class TaTouristServiceImpl extends BaseServiceImpl<TaTouristMapper, TaTourist> implements ITaTouristService {

    @Autowired
    TaResourceMapper quotaMapper;

    @Override
    public IPage<TaTourist> getPagedBy(IPage<TaTourist> pg, String touristName, String cityId) {
        return baseMapper.getPagedBy(pg, touristName, cityId);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean createNew(TaTourist taTourist) throws Exception {
        boolean isSuccess = save(taTourist);
        if (!isSuccess) return false;

        ResourceFieldVO resourceVO = copyProperties(taTourist);

        TaResource taResource = new TaResource();
        BeanUtils.copyProperties(resourceVO, taResource);
        taResource.setTargetType(Constants.TARGET_TOURIST);
        taResource.setTargetId(taTourist.getTouristId());
        int row = quotaMapper.insert(taResource);

        return row > 0;
    }

    @Override
    public ResourceFieldVO copyProperties(TaTourist taTourist) {
        ResourceFieldVO resourceVO = new ResourceFieldVO();
        BeanUtils.copyProperties(taTourist, resourceVO);
        if (!StringUtils.isEmpty(taTourist.getLocaton())) {
            String[] loc = taTourist.getLocaton().split(",");
            resourceVO.setLng(loc[0].trim());
            resourceVO.setLat(loc[1].trim());
        }
        return  resourceVO;
    }
}
